aboutsummaryrefslogtreecommitdiffstats
path: root/p2p/server.go
diff options
context:
space:
mode:
Diffstat (limited to 'p2p/server.go')
-rw-r--r--p2p/server.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/p2p/server.go b/p2p/server.go
index 4d1437d80..9c148ba39 100644
--- a/p2p/server.go
+++ b/p2p/server.go
@@ -9,7 +9,7 @@ import (
"sync"
"time"
- "github.com/ethereum/go-ethereum/ethutil"
+ "github.com/ethereum/go-ethereum/common"
"github.com/ethereum/go-ethereum/logger"
"github.com/ethereum/go-ethereum/p2p/discover"
"github.com/ethereum/go-ethereum/p2p/nat"
@@ -46,7 +46,7 @@ type Server struct {
MaxPeers int
// Name sets the node name of this server.
// Use ethutil.MakeName to create a name that follows existing conventions.
Name string
// Bootstrap nodes are used to establish connectivity
@@ -132,7 +132,7 @@ func (srv *Server) SuggestPeer(n *discover.Node) {
func (srv *Server) Broadcast(protocol string, code uint64, data ...interface{}) {
var payload []byte
if data != nil {
- payload = ethutil.Encode(data)
+ payload = common.Encode(data)
}
srv.lock.RLock()
defer srv.lock.RUnlock()
@@ -46,7 +46,7 @@ type Server struct {
MaxPeers int
// Name sets the node name of this server.
- // Use ethutil.MakeName to create a name that follows existing conventions.
+ // Use common.MakeName to create a name that follows existing conventions.
Name string
// Bootstrap nodes are used to establish connectivity